khoca: Khoca as pip installable package
=======================================

Description
-----------

Khoca as pip installable package

License
-------

GPLv2+

Upstream Contact
----------------

https://pypi.org/project/khoca/

